@@ -1,6 +1,6 @@
 package Bundle::CVSMonitor;
 
-$VERSION = 0.5;
+$VERSION = 0.6;
 
 1;
 
@@ -16,12 +16,16 @@ C<perl -MCPAN -e 'install Bundle::CVSMonitor'>
 
 =head1 CONTENTS
 
+Array::Window
+
 CGI
 
 CGI::Carp          - For it's fatalsToBrowser
 
 Chart::Math::Axis  - Calculate correct graph axis
 
+Clone
+
 Cwd
 
 Class::Autouse     - Dynamic module loading
@@ -64,6 +68,8 @@ Time::Duration
 
 Time::ParseDate
 
+URI::Escape
+
 Validate::Net
 
 Yes, we use a lot of shit. Some of these won't get used directly, but are used
